@@ -3,12 +3,12 @@ use crate::parse_file::parse_file;
 use error::Error;
 
 #[derive(Debug)]
-pub struct Module {
-    pub name: String,
-    pub queries: Vec<ParsedQuery>,
+pub(crate) struct Module {
+    pub(crate) name: String,
+    pub(crate) queries: Vec<ParsedQuery>,
 }
 
-pub fn read_queries(path: &str) -> Result<Vec<Module>, Error> {
+pub(crate) fn read_queries(path: &str) -> Result<Vec<Module>, Error> {
     let mut modules = Vec::new();
     for entry_result in std::fs::read_dir(path)? {
         let entry = entry_result?;
@@ -19,8 +19,12 @@ pub fn read_queries(path: &str) -> Result<Vec<Module>, Error> {
             .map(|extension| extension == "sql")
             .unwrap_or_default()
         {
-            // ![unwrap] We just checked that this is a file with an extension
-            let module_name = path.file_stem().unwrap().to_str().unwrap().to_string();
+            let module_name = path
+                .file_stem()
+                .expect("is a file")
+                .to_str()
+                .expect("file stem is valid utf8")
+                .to_string();
 
             let module = Module {
                 name: module_name,
@@ -35,7 +39,7 @@ pub fn read_queries(path: &str) -> Result<Vec<Module>, Error> {
     Ok(modules)
 }
 
-pub mod error {
+pub(crate) mod error {
     use crate::parse_file::error::Error as FileParserError;
     use thiserror::Error as ThisError;
 
